@@ -29,6 +29,10 @@
 #include <X11/Xlib.h>
 #define EV_METADATA_NAMESPACE "metadata::atril"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 typedef struct {
 	xmlNodePtr cur;
 	xmlChar *uri;
